@@ -2,5 +2,7 @@ from .hello import *
 from .bye import *
 from .education import *
 from .project import *
+from .experience import *
+from .contact import *
 
 from .sidd import *
